summaryrefslogtreecommitdiffstats
path: root/jjb
diff options
context:
space:
mode:
Diffstat (limited to 'jjb')
-rw-r--r--jjb/apex/apex.yml17
-rw-r--r--jjb/armband/armband-ci-jobs.yml2
-rwxr-xr-xjjb/armband/armband-deploy.sh12
-rwxr-xr-xjjb/armband/armband-download-artifact.sh42
-rw-r--r--jjb/fuel/fuel-ci-jobs.yml38
-rwxr-xr-xjjb/fuel/fuel-deploy.sh4
-rw-r--r--jjb/functest/functest-ci-jobs.yml13
-rw-r--r--jjb/joid/joid-deploy.sh9
-rw-r--r--jjb/netready/netready.yml55
-rw-r--r--jjb/opnfv/opnfv-docker.sh14
-rw-r--r--jjb/opnfv/opnfv-docker.yml1
11 files changed, 167 insertions, 40 deletions
diff --git a/jjb/apex/apex.yml b/jjb/apex/apex.yml
index 282ae7b54..ce673b288 100644
--- a/jjb/apex/apex.yml
+++ b/jjb/apex/apex.yml
@@ -212,12 +212,15 @@
properties:
- build-blocker:
use-build-blocker: true
+ block-level: 'NODE'
blocking-jobs:
- 'apex-daily.*{stream1}'
- 'apex-deploy.*{stream1}'
- 'apex-build.*{stream1}'
- 'apex-runner.*{stream1}'
- 'apex-verify-{stream1}'
+ - throttle:
+ max-per-node: 1
builders:
- 'apex-build'
@@ -230,11 +233,12 @@
block: true
same-node: true
# - trigger-builds:
-# - project: 'functest-apex-{slave}-suite-{stream1}'
+# - project: 'functest-apex-{verify-slave}-suite-{stream1}'
# predefined-parameters: |
# DEPLOY_SCENARIO=os-nosdn-nofeature-ha
# FUNCTEST_SUITE_NAME=vping_userdata
# block: true
+# same-node: true
- trigger-builds:
- project: 'apex-deploy-virtual-os-odl_l2-nofeature-ha-{stream1}'
predefined-parameters: |
@@ -313,7 +317,7 @@
# Required Variables:
# stream: branch with - in place of / (eg. stable)
# branch: branch (eg. stable)
- node: '{slave}'
+ node: '{daily-slave}'
disabled: false
@@ -338,8 +342,11 @@
properties:
- build-blocker:
use-build-blocker: true
+ block-level: 'NODE'
blocking-jobs:
- 'apex-deploy.*{stream}'
+ - throttle:
+ max-per-node: 1
builders:
- 'apex-build'
@@ -349,6 +356,7 @@
BUILD_DIRECTORY=apex-build-{stream}/build
OPNFV_CLEAN=yes
git-revision: false
+ same-node: true
block: true
- 'apex-upload-artifact'
@@ -387,8 +395,11 @@
properties:
- build-blocker:
use-build-blocker: true
+ block-level: 'NODE'
blocking-jobs:
- 'apex-deploy.*{stream}'
+ - throttle:
+ max-per-node: 1
builders:
- 'apex-deploy-virtual'
@@ -604,6 +615,7 @@
properties:
- build-blocker:
use-build-blocker: true
+ block-level: 'NODE'
blocking-jobs:
- 'apex-verify.*{stream1}'
- 'apex-deploy.*{stream1}'
@@ -618,6 +630,7 @@
- project: 'apex-build-{stream1}'
git-revision: true
current-parameters: true
+ same-node: true
block: true
- trigger-builds:
- project: 'apex-deploy-virtual-nosdn-nofeature-ha-{stream1}'
diff --git a/jjb/armband/armband-ci-jobs.yml b/jjb/armband/armband-ci-jobs.yml
index 5ae8a04dc..bbf7c40a4 100644
--- a/jjb/armband/armband-ci-jobs.yml
+++ b/jjb/armband/armband-ci-jobs.yml
@@ -190,4 +190,4 @@
- trigger:
name: 'armband-os-odl_l2-nofeature-ha-arm-pod1-brahmaputra-trigger'
triggers:
- - timed: '0 4 * * *'
+ - timed: '0 20 * * *'
diff --git a/jjb/armband/armband-deploy.sh b/jjb/armband/armband-deploy.sh
index 97430c114..8b0af31e3 100755
--- a/jjb/armband/armband-deploy.sh
+++ b/jjb/armband/armband-deploy.sh
@@ -39,10 +39,10 @@ POD_NAME=${NODE_NAME/*-}
if [[ ! $LAB_NAME =~ (arm|enea) ]]; then
echo "Unsupported/unidentified lab $LAB_NAME. Cannot continue!"
exit 1
-else
- echo "Using configuration for $LAB_NAME"
fi
+echo "Using configuration for $LAB_NAME"
+
# create TMPDIR if it doesn't exist
mkdir -p $TMPDIR
@@ -52,8 +52,11 @@ if [[ $LAB_CONFIG_URL =~ ^git:// ]]; then
LAB_CONFIG_URL=file://${WORKSPACE}/lab-config
fi
+# releng wants us to use nothing else but opnfv.iso for now. We comply.
+ISO_FILE=$WORKSPACE/opnfv.iso
+
# construct the command
-DEPLOY_COMMAND="$WORKSPACE/ci/deploy.sh -b ${LAB_CONFIG_URL} -l $LAB_NAME -p $POD_NAME -s $DEPLOY_SCENARIO -i file://$WORKSPACE/opnfv.iso -H -B $BRIDGE -S $TMPDIR"
+DEPLOY_COMMAND="$WORKSPACE/ci/deploy.sh -l $LAB_NAME -p $POD_NAME -b ${LAB_CONFIG_URL} -s $DEPLOY_SCENARIO -i file://${ISO_FILE} -H -B $BRIDGE -S $TMPDIR"
# log info to console
echo "Deployment parameters"
@@ -72,9 +75,6 @@ echo "Issuing command"
echo "$DEPLOY_COMMAND"
echo
-# FIXME
-export TARGET_LAB=${LAB_NAME}
-export TARGET_POD=${POD_NAME}
$DEPLOY_COMMAND
echo
diff --git a/jjb/armband/armband-download-artifact.sh b/jjb/armband/armband-download-artifact.sh
index 15ad67d6e..18b55d7a7 100755
--- a/jjb/armband/armband-download-artifact.sh
+++ b/jjb/armband/armband-download-artifact.sh
@@ -13,35 +13,33 @@ set -o pipefail
if [[ "$JOB_NAME" =~ "merge" ]]; then
echo "Downloading http://$GS_URL/opnfv-gerrit-$GERRIT_CHANGE_NUMBER.properties"
# get the properties file for the Armband Fuel ISO built for a merged change
- curl -s -o $WORKSPACE/latest.properties http://$GS_URL/opnfv-gerrit-$GERRIT_CHANGE_NUMBER.properties
+ curl -f -s -o $WORKSPACE/latest.properties http://$GS_URL/opnfv-gerrit-$GERRIT_CHANGE_NUMBER.properties
else
# get the latest.properties file in order to get info regarding latest artifact
echo "Downloading http://$GS_URL/latest.properties"
- curl -s -o $WORKSPACE/latest.properties http://$GS_URL/latest.properties
+ curl -f -s -o $WORKSPACE/latest.properties http://$GS_URL/latest.properties
fi
-# check if we got the file
-# FIXME: the file is created even if it didn't exist on the host
-# We should check that the contents are sane
-[[ -f latest.properties ]] || exit 1
-
-# source the file so we get artifact metadata
+# source the file so we get artifact metadata, it will exit if it doesn't exist
source latest.properties
# echo the info about artifact that is used during the deployment
OPNFV_ARTIFACT=${OPNFV_ARTIFACT_URL/*\/}
echo "Using $OPNFV_ARTIFACT for deployment"
+# Releng doesn't want us to use anything but opnfv.iso for now. We comply.
+ISO_FILE=${WORKSPACE}/opnfv.iso
+
# using ISOs for verify & merge jobs from local storage will be enabled later
if [[ ! "$JOB_NAME" =~ (verify|merge) ]]; then
# check if we already have the ISO to avoid redownload
ISOSTORE="/iso_mount/opnfv_ci/${GIT_BRANCH##*/}"
if [[ -f "$ISOSTORE/$OPNFV_ARTIFACT" ]]; then
echo "ISO exists locally. Skipping the download and using the file from ISO store"
- ln -s $ISOSTORE/$OPNFV_ARTIFACT $WORKSPACE/opnfv.iso
+ ln -s $ISOSTORE/$OPNFV_ARTIFACT ${ISO_FILE}
echo "--------------------------------------------------------"
echo
- ls -al $WORKSPACE/opnfv.iso
+ ls -al ${ISO_FILE}
echo
echo "--------------------------------------------------------"
echo "Done!"
@@ -49,18 +47,22 @@ if [[ ! "$JOB_NAME" =~ (verify|merge) ]]; then
fi
fi
+# Use gsutils if available
+if $(which gsutil &>/dev/null); then
+ DOWNLOAD_URL="gs://$OPNFV_ARTIFACT_URL"
+ CMD="gsutil cp ${DOWNLOAD_URL} ${ISO_FILE}"
+else
+ # download image
+ # -f returns error if the file was not found or on server error
+ DOWNLOAD_URL="http://$OPNFV_ARTIFACT_URL"
+ CMD="curl -f -s -o ${ISO_FILE} ${DOWNLOAD_URL}"
+fi
+
# log info to console
-echo "Downloading the $INSTALLER_TYPE artifact using URL http://$OPNFV_ARTIFACT_URL"
+echo "Downloading the $INSTALLER_TYPE artifact using URL $DOWNLOAD_URL"
echo "This could take some time..."
echo "--------------------------------------------------------"
-echo
-
-# download the file
-curl -s -o $WORKSPACE/opnfv.iso http://$OPNFV_ARTIFACT_URL
-
-# The file is always created, check that it is in fact an ISO image
-[[ $(file $WORKSPACE/opnfv.iso) =~ ISO ]]
-
-echo
+echo "$CMD"
+$CMD
echo "--------------------------------------------------------"
echo "Done!"
diff --git a/jjb/fuel/fuel-ci-jobs.yml b/jjb/fuel/fuel-ci-jobs.yml
index 77b711e74..acfcedabf 100644
--- a/jjb/fuel/fuel-ci-jobs.yml
+++ b/jjb/fuel/fuel-ci-jobs.yml
@@ -43,6 +43,8 @@
<<: *master
- virtual:
<<: *master
+ - zte-pod1:
+ <<: *master
#--------------------------------
# scenarios
#--------------------------------
@@ -311,6 +313,42 @@
name: 'fuel-os-nosdn-kvm-noha-ericsson-pod2-brahmaputra-trigger'
triggers:
- timed: ''
+
+#-----------------------------------------------
+# ZTE POD1 Triggers running against master branch
+#-----------------------------------------------
+- trigger:
+ name: 'fuel-os-nosdn-nofeature-ha-zte-pod1-master-trigger'
+ triggers:
+ - timed: ''
+- trigger:
+ name: 'fuel-os-odl_l2-nofeature-ha-zte-pod1-master-trigger'
+ triggers:
+ - timed: '0 12 * * *'
+- trigger:
+ name: 'fuel-os-odl_l3-nofeature-ha-zte-pod1-master-trigger'
+ triggers:
+ - timed: ''
+- trigger:
+ name: 'fuel-os-onos-nofeature-ha-zte-pod1-master-trigger'
+ triggers:
+ - timed: ''
+- trigger:
+ name: 'fuel-os-odl_l2-bgpvpn-ha-zte-pod1-master-trigger'
+ triggers:
+ - timed: ''
+- trigger:
+ name: 'fuel-os-odl_l2-sfc-ha-zte-pod1-master-trigger'
+ triggers:
+ - timed: ''
+- trigger:
+ name: 'fuel-os-nosdn-kvm-ha-zte-pod1-master-trigger'
+ triggers:
+ - timed: ''
+- trigger:
+ name: 'fuel-os-nosdn-ovs-ha-zte-pod1-master-trigger'
+ triggers:
+ - timed: ''
#-----------------------------------------------
# Triggers for other PODs
#-----------------------------------------------
diff --git a/jjb/functest/functest-ci-jobs.yml b/jjb/functest/functest-ci-jobs.yml
index 6cfcfdca4..cd3f11e8e 100644
--- a/jjb/functest/functest-ci-jobs.yml
+++ b/jjb/functest/functest-ci-jobs.yml
@@ -218,12 +218,20 @@
builders:
- 'functest-cleanup'
- 'set-functest-env'
- - 'functest-all'
+ - 'functest-daily'
- 'functest-store-results'
- builder:
name: functest-suite-builder
builders:
+ - 'functest-cleanup'
+ - 'set-functest-env'
+ - 'functest-suite'
+
+
+- builder:
+ name: functest-suite
+ builders:
- shell: |
#!/bin/bash
set -e
@@ -237,8 +245,9 @@
container_id=$(docker ps -a | grep opnfv/functest | awk '{print $1}' | head -1)
docker exec $container_id $cmd
+
- builder:
- name: functest-all
+ name: functest-daily
builders:
- shell: |
#!/bin/bash
diff --git a/jjb/joid/joid-deploy.sh b/jjb/joid/joid-deploy.sh
index 907db4f57..bcc4b6412 100644
--- a/jjb/joid/joid-deploy.sh
+++ b/jjb/joid/joid-deploy.sh
@@ -181,10 +181,17 @@ cat << EOF > $JOID_ADMIN_OPENRC
export OS_USERNAME=admin
export OS_PASSWORD=$OS_ADMIN_PASSWORD
export OS_TENANT_NAME=admin
-export OS_AUTH_URL=http://$KEYSTONE:5000/v2.0
+export OS_AUTH_URL=http://$KEYSTONE:35537/v2.0
export OS_REGION_NAME=Canonical
+export OS_ENDPOINT_TYPE='adminURL'
+export CINDER_ENDPOINT_TYPE='adminURL'
+export GLANCE_ENDPOINT_TYPE='adminURL'
+export KEYSTONE_ENDPOINT_TYPE='adminURL'
+export NEUTRON_ENDPOINT_TYPE='adminURL'
+export NOVA_ENDPOINT_TYPE='adminURL'
export SDN_CONTROLLER=$SDN_CONTROLLER_IP
export SDN_PASSWORD=$SDN_PASSWORD
+export OS_INTERFACE=admin
EOF
##
diff --git a/jjb/netready/netready.yml b/jjb/netready/netready.yml
new file mode 100644
index 000000000..bc8f66691
--- /dev/null
+++ b/jjb/netready/netready.yml
@@ -0,0 +1,55 @@
+- project:
+ name: netready
+
+ project: '{name}'
+
+ jobs:
+ - 'netready-verify-{stream}'
+
+ stream:
+ - master:
+ branch: '{stream}'
+ gs-pathname: ''
+ - brahmaputra:
+ branch: 'stable/{stream}'
+ gs-pathname: '/{stream}'
+
+- job-template:
+ name: 'netready-verify-{stream}'
+
+ parameters:
+ - project-parameter:
+ project: '{project}'
+ - gerrit-parameter:
+ branch: '{branch}'
+ scm:
+ - gerrit-trigger-scm:
+ credentials-id: '{ssh-credentials}'
+ refspec: '$GERRIT_REFSPEC'
+ choosing-strategy: 'gerrit'
+
+ triggers:
+ - gerrit:
+ trigger-on:
+ - patchset-created-event:
+ exclude-drafts: 'false'
+ exclude-trivial-rebase: 'false'
+ exclude-no-code-change: 'false'
+ - draft-published-event
+ - comment-added-contains-event:
+ comment-contains-value: 'recheck'
+ - comment-added-contains-event:
+ comment-contains-value: 'reverify'
+ projects:
+ - project-compare-type: 'ANT'
+ project-pattern: '{project}'
+ branches:
+ - branch-compare-type: 'ANT'
+ branch-pattern: '**/{branch}'
+ forbidden-file-paths:
+ - compare-type: ANT
+ pattern: 'docs/**'
+
+ builders:
+ - shell: |
+ echo "Nothing to verify!"
diff --git a/jjb/opnfv/opnfv-docker.sh b/jjb/opnfv/opnfv-docker.sh
index 702c0ce52..1093d5fec 100644
--- a/jjb/opnfv/opnfv-docker.sh
+++ b/jjb/opnfv/opnfv-docker.sh
@@ -67,16 +67,18 @@ fi
# cd to directory where Dockerfile is located
-if [[ "$DOCKER_REPO_NAME" == "opnfv/functest" ]]; then
+if [[ "$DOCKER_REPO_NAME" == "opnfv/bottlenecks" ]]; then
+ cd $WORKSPACE/ci/docker
+elif [[ "$DOCKER_REPO_NAME" == "opnfv/cperf" ]]; then
cd $WORKSPACE/docker
-elif [[ "$DOCKER_REPO_NAME" == "opnfv/yardstick" ]]; then
- cd $WORKSPACE/ci/docker/yardstick-ci
-elif [[ "$DOCKER_REPO_NAME" == "opnfv/storperf" ]]; then
+elif [[ "$DOCKER_REPO_NAME" == "opnfv/functest" ]]; then
cd $WORKSPACE/docker
elif [[ "$DOCKER_REPO_NAME" == "opnfv/qtip" ]]; then
cd $WORKSPACE/docker
-elif [[ "$DOCKER_REPO_NAME" == "opnfv/bottlenecks" ]]; then
- cd $WORKSPACE/ci/docker
+elif [[ "$DOCKER_REPO_NAME" == "opnfv/storeperf" ]]; then
+ cd $WORKSPACE/docker
+elif [[ "$DOCKER_REPO_NAME" == "opnfv/yardstick" ]]; then
+ cd $WORKSPACE/ci/docker/yardstick-ci
else
echo "ERROR: DOCKER_REPO_NAME parameter not valid: $DOCKER_REPO_NAME"
exit 1
diff --git a/jjb/opnfv/opnfv-docker.yml b/jjb/opnfv/opnfv-docker.yml
index 936f22040..6b4924295 100644
--- a/jjb/opnfv/opnfv-docker.yml
+++ b/jjb/opnfv/opnfv-docker.yml
@@ -8,6 +8,7 @@
project:
- 'bottlenecks'
+ - 'cperf'
- 'functest'
- 'storperf'
- 'qtip'
diff --git a/jjb/fuel/fuel-deploy.sh b/jjb/fuel/fuel-deploy.sh
index bab6151d8..ceccc54b6 100755
--- a/jjb/fuel/fuel-deploy.sh
+++ b/jjb/fuel/fuel-deploy.sh
@@ -43,8 +43,8 @@ if [[ "$NODE_NAME" =~ "virtual" ]]; then
POD_NAME="virtual_kvm"
fi
-# we currently support ericsson, intel, and lf labs
-if [[ ! "$LAB_NAME" =~ (ericsson|intel|lf) ]]; then
+# we currently support ericsson, intel, lf and zte labs
+if [[ ! "$LAB_NAME" =~ (ericsson|intel|lf|zte) ]]; then
echo "Unsupported/unidentified lab $LAB_NAME. Cannot continue!"
exit 1
else